---
title: <span class="badge builder"></span> AnnotationPanelFilter
---
# <span class="badge builder"></span> AnnotationPanelFilter

## Constructor

```python
AnnotationPanelFilter()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.AnnotationPanelFilter
```

### <span class="badge object-method"></span> exclude

Should the specified panels be included or excluded

```python
def exclude(exclude: bool) -> typing.Self
```

### <span class="badge object-method"></span> ids

Panel IDs that should be included or excluded

```python
def ids(ids: list[int]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [AnnotationPanelFilter](./object-AnnotationPanelFilter.md)
